Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorckamm <mail@ckamm.de>2016-12-06 12:55:58 +0300
committerGitHub <noreply@github.com>2016-12-06 12:55:58 +0300
commit5bef1aa402d600c658ddbdb0efde819bfc178516 (patch)
treeab873d4276873f2690a417ceb0ef1a2fac3c1660 /src/gui/folderman.h
parentde9ea19e7e49ae2ddfe94114ad8b55f66f154c20 (diff)
parenta139d1a2799c125f2ffe435338e705a7416cd33b (diff)
Merge pull request #5045 from owncloud/dbjournal_per_account
Allow a folder to be synced to several accounts. This changes the path of the sync journal file!
Diffstat (limited to 'src/gui/folderman.h')
-rw-r--r--src/gui/folderman.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/gui/folderman.h b/src/gui/folderman.h
index bc627587b..911db7089 100644
--- a/src/gui/folderman.h
+++ b/src/gui/folderman.h
@@ -97,11 +97,11 @@ public:
Folder* setupFolderFromOldConfigFile(const QString &, AccountState *account );
/**
* Ensures that a given directory does not contain a .csync_journal.
*
* @returns false if the journal could not be removed, true otherwise.
*/
- static bool ensureJournalGone(const QString &path);
+ static bool ensureJournalGone(const QString& journalDbFile);
/** Creates a new and empty local directory. */
bool startFromScratch( const QString& );
@@ -128,7 +128,7 @@ public:
*
* @returns an empty string if it is allowed, or an error if it is not allowed
*/
- QString checkPathValidityForNewFolder(const QString &path, bool forNewDirectory = false);
+ QString checkPathValidityForNewFolder(const QString &path, const QUrl& serverUrl = QUrl(), bool forNewDirectory = false);
/**
* While ignoring hidden files can theoretically be switched per folder,
@@ -261,7 +261,8 @@ private:
/** Adds a new folder, does not add it to the account settings and
* does not set an account on the new folder.
*/
- Folder* addFolderInternal(FolderDefinition folderDefinition, AccountState* accountState);
+ Folder* addFolderInternal(FolderDefinition folderDefinition,
+ AccountState* accountState);
/* unloads a folder object, does not delete it */
void unloadFolder( Folder * );
@@ -277,6 +278,8 @@ private:
// restarts the application (Linux only)
void restartApplication();
+ void setupFoldersHelper(QSettings& settings, AccountStatePtr account, bool backwardsCompatible);
+
QSet<Folder*> _disabledFolders;
Folder::Map _folderMap;
QString _folderConfigPath;
@@ -97,11 +97,11 @@ public:
Folder* setupFolderFromOldConfigFile(const QString &, AccountState *account );
/**
- * Ensures that a given directory does not contain a .csync_journal.
+ * Ensures that a given directory does not contain a sync journal file.
*
* @returns false if the journal could not be removed, true otherwise.